summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--commands/hardware/lmi/scripts/hardware/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/commands/hardware/lmi/scripts/hardware/__init__.py b/commands/hardware/lmi/scripts/hardware/__init__.py
index 594258e..fc52c16 100644
--- a/commands/hardware/lmi/scripts/hardware/__init__.py
+++ b/commands/hardware/lmi/scripts/hardware/__init__.py
@@ -55,9 +55,9 @@ def get_all_info(ns):
def get_system_info(ns):
"""
:returns: Tabular data from ``Linux_ComputerSystem`` instance.
"""
- i = get_single_instance(ns, 'Linux_ComputerSystem')
+ i = get_single_instance(ns, 'CIM_ComputerSystem')
return [('Hostname:', i.Name)]
def get_chassis_info(ns):
@@ -55,9 +55,9 @@ def get_all_info(ns):
def get_system_info(ns):
"""
- :returns: Tabular data from ``Linux_ComputerSystem`` instance.
+ :returns: Tabular data from ``CIM_ComputerSystem`` instance.
"""